pub struct MultivariateNormal<Real, N>where
Real: RealField,
N: Dim + DimMin<N, Output = N>,
DefaultAllocator: Allocator<N> + Allocator<N, N> + Allocator<U1, N> + Allocator<<N as DimMin<N>>::Output>,{ /* private fields */ }Expand description
An N-dimensional multivariate normal distribution
See the crate-level docs for example usage.
Implementations
Sourceimpl<Real, N> MultivariateNormal<Real, N>
impl<Real, N> MultivariateNormal<Real, N>
Sourcepub fn from_mean_and_precision(
mu: &OVector<Real, N>,
precision: &OMatrix<Real, N, N>,
) -> Self
pub fn from_mean_and_precision( mu: &OVector<Real, N>, precision: &OMatrix<Real, N, N>, ) -> Self
Create a multivariate normal distribution from a mean and precision
The mean vector mu is N dimensional and the precision matrix is
N x N.
Sourcepub fn from_mean_and_covariance(
mu: &OVector<Real, N>,
covariance: &OMatrix<Real, N, N>,
) -> Result<Self, Error>
pub fn from_mean_and_covariance( mu: &OVector<Real, N>, covariance: &OMatrix<Real, N, N>, ) -> Result<Self, Error>
Create a multivariate normal distribution from a mean and covariance
The mean vector mu is N dimensional and the covariance matrix is
N x N.
The precision matrix is calculated by inverting the covariance matrix using a Cholesky decomposition. This can fail if the covariance matrix is not definite positive.
Sourcepub fn pdf<Count>(&self, xs: &OMatrix<Real, Count, N>) -> OVector<Real, Count>
pub fn pdf<Count>(&self, xs: &OMatrix<Real, Count, N>) -> OVector<Real, Count>
Probability density function
Evaluate the probability density at locations xs.